@@ -15,7 +15,6 @@ import re
 import traceback
 
 from pyvows.color import yellow, green, red, bold
-from pyvows.errors import VowsAssertionError
 
 __all__ = [
     'PROGRESS_SIZE',
@@ -95,7 +94,7 @@ class VowsReporter(object):
         #   ...Is this a decorator?  If so, please add a comment or docstring
         #   to make it explicit.
         def _indent(msg):
-            if msg.startswith('  File'):
+            if msg.strip().startswith('File'):
                 return self.indent_msg(msg)
             return msg
 
